@@ -387,6 +387,7 @@ soup_session_add_filter (SoupSession *session, SoupMessageFilter *filter)
 	g_return_if_fail (SOUP_IS_SESSION (session));
 	g_return_if_fail (SOUP_IS_MESSAGE_FILTER (filter));
 
+	g_object_ref (filter);
 	session->priv->filters = g_slist_prepend (session->priv->filters,
 						  filter);
 }
@@ -406,6 +407,7 @@ soup_session_remove_filter (SoupSession *session, SoupMessageFilter *filter)
 
 	session->priv->filters = g_slist_remove (session->priv->filters,
 						 filter);
+	g_object_unref (filter);
 }
 
 
@@ -800,8 +802,6 @@ add_auth (SoupSession *session, SoupMessage *msg, gboolean proxy)
 	SoupAuth *auth;
 	char *token;
 
-	soup_message_remove_header (msg->request_headers, header);
-
 	auth = lookup_auth (session, msg, proxy);
 	if (!auth)
 		return;
@@ -811,6 +811,7 @@ add_auth (SoupSession *session, SoupMessage *msg, gboolean proxy)
 
 	token = soup_auth_get_authorization (auth, msg);
 	if (token) {
+		soup_message_remove_header (msg->request_headers, header);
 		soup_message_add_header (msg->request_headers, header, token);
 		g_free (token);
 	}
