@@ -69,7 +69,8 @@ fetch_ns (SoupSoapMessage *msg, const char *prefix, const char *ns_uri)
                 ns = xmlNewNs (msg->priv->last_node, ns_uri, prefix);
         else if (prefix && !ns_uri) {
                 ns = xmlSearchNs (msg->priv->doc, msg->priv->last_node, prefix);
-                if (!ns) ns = xmlNewNs (msg->priv->last_node, "", prefix);
+                if (!ns)
+			ns = xmlNewNs (msg->priv->last_node, "", prefix);
         }
                                                                                 
         return ns;
@@ -175,6 +176,9 @@ soup_soap_message_start_envelope (SoupSoapMessage *msg)
 	xmlNewNs (msg->priv->doc->xmlRootNode,
                   "http://www.w3.org/1999/XMLSchema",
                   "xsd");
+	xmlNewNs (msg->priv->doc->xmlRootNode,
+		  "http://schemas.xmlsoap.org/soap/envelope/",
+		  "SOAP-ENV");
 	msg->priv->xsi_ns = xmlNewNs (msg->priv->doc->xmlRootNode,
 				      "http://www.w3.org/1999/XMLSchema-instance",
 				      "xsi");
